@@ -10,32 +10,30 @@
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
-import os
-import sys
 
+import sys
+import os
 
 sys.path.insert(0, os.path.abspath('../../src/'))
 sys.path.insert(0, os.path.abspath('.'))
 
+from daf import VERSION
+
 
 # -- Project information -----------------------------------------------------
 project = 'Discord Advertisement Framework'
 copyright = '2023, David Hozic'
 author = 'David Hozic'
-version = None
-gh_release = os.environ.get("GITHUB_REF_NAME", default=None) # Workflow run release
-readthedocs_release = os.environ.get("READTHEDOCS_VERSION", default=None) # Readthe docs version
-if gh_release is not None:
-    version = gh_release
-elif readthedocs_release is not None:
-    version = readthedocs_release
-else:
-    version = "v0.0.1"
+version = VERSION
 
 
 # -- General configuration ---------------------------------------------------
 root_doc = 'index'
 
+rst_prolog = """
+.. |ASYNC_API| replace:: This is an asynchronous API operation. When returning from this function, the action is not immediately executed.
+"""
+
 numfig = True
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
@@ -90,7 +88,7 @@ intersphinx_mapping = {
 
 # ----------- HTML ----------- #
 html_title = project
-html_logo = "./DEP/images/logo.png"
+html_logo = "./DEP/logo.png"
 html_favicon = html_logo
 html_theme = 'furo'
 html_static_path = ['_static']
@@ -111,3 +109,4 @@ html_theme_options = {
 }
 
 # ----------- Latex ----------- #
+latex_logo = html_logo
