@@ -10,33 +10,39 @@
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
-import os
 import sys
-
+import os
 
 sys.path.insert(0, os.path.abspath('../../src/'))
 sys.path.insert(0, os.path.abspath('.'))
+sys.path.append(os.path.abspath("./ext/"))
 
+from daf import VERSION
+
+
+language = os.environ["LANGUAGE"]
+
+root_doc = f"{language}/index"
+exclude_patterns = ["sl/**", "en/**"]
+
+exclude_patterns.remove(f"{language}/**")
 
 # -- Project information -----------------------------------------------------
-project = 'Discord Advertisement Framework'
+project = "daf-thesis"
 copyright = '2023, David Hozic'
 author = 'David Hozic'
-version = None
-gh_release = os.environ.get("GITHUB_REF_NAME", default=None) # Workflow run release
-readthedocs_release = os.environ.get("READTHEDOCS_VERSION", default=None) # Readthe docs version
-if gh_release is not None:
-    version = gh_release
-elif readthedocs_release is not None:
-    version = readthedocs_release
-else:
-    version = "v0.0.1"
+version = VERSION
 
 
 # -- General configuration ---------------------------------------------------
-root_doc = 'index'
-
 numfig = True
+
+rst_epilog = r"""
+.. raw:: latex
+
+    \newpage
+"""
+
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
@@ -49,7 +55,7 @@ extensions = [
     "enum_tools.autoenum",
     "sphinx_design",
     "sphinx_search.extension",
-    "sphinxcontrib.inkscapeconverter"
+    "sphinxcontrib.inkscapeconverter",
 ]
 
 
@@ -62,12 +68,6 @@ source_suffix = {
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
 
-# List of patterns, relative to source directory, that match files and
-# directories to ignore when looking for source files.
-# This pattern also affects html_static_path and html_extra_path.
-exclude_patterns = []
-
-
 # Autodoc
 autodoc_typehints = "signature"
 autodoc_typehints_format = "short"
@@ -82,18 +82,20 @@ autodoc_default_options = {
 }
 
 
-
 # Intersphinx
 intersphinx_mapping = {
-    'PyCord': ("https://docs.pycord.dev/en/stable/", None),
-    "DAF" : ("https://daf.davidhozic.com/en/stable/", None),
-    "Python" : ("https://docs.python.org/3/", None),
-    "Sphinx" : ("https://www.sphinx-doc.org/en/master", None)
+    'PyCord': ("https://docs.pycord.dev/en/v2.4.x/", None),
+    "DAF": ("https://daf.davidhozic.com/en/v2.9.x/", None),
+    "Python": ("https://docs.python.org/3/", None),
+    "Sphinx": ("https://www.sphinx-doc.org/en/master", None),
+    "SQLAlchemy": ("https://docs.sqlalchemy.org/en/20/", None),
 }
 
+
+
 # ----------- HTML ----------- #
 html_title = project
-html_logo = "./DEP/images/logo.png"
+html_logo = "./DEP/logo.png"
 html_favicon = html_logo
 html_theme = 'furo'
 html_static_path = ['_static']
@@ -114,47 +116,93 @@ html_theme_options = {
 }
 
 # ----------- Latex ----------- #
-with open("titlepage.tex", "r", encoding="utf-8") as reader:
+with open(f"./{language}/titlepage.tex", "r", encoding="utf-8") as reader:
     latex_title_page = reader.read()
 
-# latex_engine = 'xelatex'
+literal_block_str = {
+    "en": r"\listof{literalblock}{Literal blocks}",
+    "sl": r"\listof{literalblock}{Bloki kode}"
+}
+
+latex_theme = "manual"  # latex class => report
 latex_elements = {
+    "figure_align": "H",
+    "sphinxsetup": r"VerbatimColor={rgb}{1,1,1},verbatimhintsturnover=false",
+    "papersize": "a4paper",
+    "pointsize": "12pt",
+    "extraclassoptions": "openright",
     "tableofcontents": r"""
         \tableofcontents
+        \newpage
         \listoffigures
-        \listof{literalblock}{List of literal blocks}
-        \listoftables
-    """,
-    'fncychap': r'',
-    # 'fontpkg': r"""
-    #     \setromanfont{Times New Roman}
-    #     \setsansfont{Arial}
-    #     """,
-    "papersize" : "a4paper",
-    "pointsize" : "12pt",
-    'preamble': r'''
-        \usepackage{afterpage}
+        \newpage
+        {}
+    """.format(literal_block_str.get(language)),
+    "fncychap": "",
+    "babel": r"\usepackage[slovene]{babel}",
+    'preamble':
+        r'''
+        % Packages
+        \usepackage[final]{pdfpages}
 
-        \newcommand\blankpage{%
-        \null
-        \thispagestyle{empty}%
-        \addtocounter{page}{-1}%
-        \newpage}
+        % Spacing
+        \textheight 215mm
+        \textwidth 145mm
+        \oddsidemargin  13mm
+        \topmargin -5mm
+        \headsep 20mm
+        \headheight 6mm
+        \evensidemargin 0mm
+        \linespread{1.2}
 
-        \oddsidemargin 1.4cm
-        \evensidemargin 0.35cm
-        \textwidth 14cm
-        \topmargin 0.26cm
-        \headheight 0.6cm
-        \headsep 1.5cm
-        \textheight 20cm
+        % Titles (titlesec)
+        \titleformat{\chapter}[hang]{\normalfont\Huge\bfseries}{\thechapter}{0.5cm}{}
+
+        % Header and footer
+        \usepackage{fancyhdr}
         \pagestyle{fancy}
-        \fancyhead{}
-        \renewcommand{\sectionmark}[1]{\markright{\textsf{\thesection\  #1}}{}}
-        \fancyhead[RE]{\leftmark}
-        \fancyhead[LO]{\rightmark}
-        \fancyhead[LE,RO]{\thepage}
-        \fancyfoot{}
+        \fancypagestyle{normal}{
+            \fancyfoot[RE]{{\nouppercase{\leftmark}}}
+        }
+
+        % New commands
+        \newcommand\blankpage{
+            \newpage
+            \thispagestyle{empty}
+            \mbox{}
+            \newpage
+        }
     ''',
-    "maketitle": latex_title_page,
+    "maketitle": rf"""
+        \includepdf{{NaslovnaStranDiplome.pdf}}
+        \blankpage
+        \includepdf{{IzjavaOAvtorstvu.pdf}}
+        \blankpage
+        {latex_title_page}
+        \blankpage
+        \pagenumbering{{roman}}
+    """,
+    "printindex": ''
 }
+
+numfig_format = {
+    "sl": {
+        "figure": "Slika %s",
+        "table": "Tabela %s",
+        "code-block": "Blok kode %s"
+    },
+}
+
+if language == "en":
+    del numfig_format
+else:
+    numfig_format = numfig_format[language]
+
+
+latex_additional_files = ["./NaslovnaStranDiplome.pdf", "./IzjavaOAvtorstvu.pdf"]
+
+
+# ----------- Docx ----------- #
+docx_documents = [
+    (f'{language}/index', 'docxbuilder.docx', {}, True),
+]
