@@ -232,8 +232,8 @@ class CogMeta(type):
         # r.e type ignore, type-checker complains about overriding a ClassVar
         new_cls.__cog_commands__ = tuple(c._update_copy(cmd_attrs) if not hasattr(c, "add_to") else c for c in new_cls.__cog_commands__)  # type: ignore
 
-        name_filter = (
-            lambda c: "app"
+        name_filter = lambda c: (
+            "app"
             if isinstance(c, ApplicationCommand)
             else ("bridge" if not hasattr(c, "add_to") else "ext")
         )
@@ -586,7 +586,10 @@ class Cog(metaclass=CogMeta):
 
         try:
             for command in self.__cog_commands__:
-                if isinstance(command, ApplicationCommand):
+                if hasattr(command, "add_to"):
+                    bot.bridge_commands.remove(command)
+                    continue
+                elif isinstance(command, ApplicationCommand):
                     bot.remove_application_command(command)
                 elif command.parent is None:
                     bot.remove_command(command.name)
@@ -735,7 +738,7 @@ class CogMixin:
                 self.remove_application_command(cmd)
 
         # remove all the listeners from the module
-        for event_list in self.extra_events.copy().values():
+        for event_list in self._event_handlers.copy().values():
             remove = [
                 index
                 for index, event in enumerate(event_list)
@@ -1019,8 +1022,10 @@ class CogMixin:
             loaded = self.load_extension(
                 ext_path, package=package, recursive=recursive, store=store
             )
-            loaded_extensions.update(loaded) if store else loaded_extensions.extend(
-                loaded
+            (
+                loaded_extensions.update(loaded)
+                if store
+                else loaded_extensions.extend(loaded)
             )
 
         return loaded_extensions
