@@ -30,6 +30,7 @@ import datetime
 import functools
 import inspect
 import re
+import sys
 import types
 from collections import OrderedDict
 from enum import Enum
@@ -64,6 +65,11 @@ from ..utils import MISSING, async_all, find, maybe_coroutine, utcnow
 from .context import ApplicationContext, AutocompleteContext
 from .options import Option, OptionChoice
 
+if sys.version_info >= (3, 11):
+    from typing import Annotated, get_args, get_origin
+else:
+    from typing_extensions import Annotated, get_args, get_origin
+
 __all__ = (
     "_BaseCommand",
     "ApplicationCommand",
@@ -84,6 +90,7 @@ if TYPE_CHECKING:
 
     from .. import Permissions
     from ..cog import Cog
+    from ..ext.commands.cooldowns import CooldownMapping, MaxConcurrency
 
 T = TypeVar("T")
 CogT = TypeVar("CogT", bound="Cog")
@@ -294,18 +301,17 @@ class ApplicationCommand(_BaseCommand, Generic[CogT, P, T]):
                 f"The check functions for the command {self.name} failed"
             )
 
-        if hasattr(self, "_max_concurrency"):
-            if self._max_concurrency is not None:
-                # For this application, context can be duck-typed as a Message
-                await self._max_concurrency.acquire(ctx)  # type: ignore # ctx instead of non-existent message
+        if self._max_concurrency is not None:
+            # For this application, context can be duck-typed as a Message
+            await self._max_concurrency.acquire(ctx)  # type: ignore # ctx instead of non-existent message
 
-            try:
-                self._prepare_cooldowns(ctx)
-                await self.call_before_hooks(ctx)
-            except:
-                if self._max_concurrency is not None:
-                    await self._max_concurrency.release(ctx)  # type: ignore # ctx instead of non-existent message
-                raise
+        try:
+            self._prepare_cooldowns(ctx)
+            await self.call_before_hooks(ctx)
+        except:
+            if self._max_concurrency is not None:
+                await self._max_concurrency.release(ctx)  # type: ignore # ctx instead of non-existent message
+            raise
 
     def is_on_cooldown(self, ctx: ApplicationContext) -> bool:
         """Checks whether the command is currently on cooldown.
@@ -647,10 +653,10 @@ class SlashCommand(ApplicationCommand):
     cooldown: Optional[:class:`~discord.ext.commands.Cooldown`]
         The cooldown applied when the command is invoked. ``None`` if the command
         doesn't have a cooldown.
-    name_localizations: Optional[Dict[:class:`str`, :class:`str`]]
+    name_localizations: Dict[:class:`str`, :class:`str`]
         The name localizations for this command. The values of this should be ``"locale": "name"``. See
         `here <https://discord.com/developers/docs/reference#locales>`_ for a list of valid locales.
-    description_localizations: Optional[Dict[:class:`str`, :class:`str`]]
+    description_localizations: Dict[:class:`str`, :class:`str`]
         The description localizations for this command. The values of this should be ``"locale": "description"``.
         See `here <https://discord.com/developers/docs/reference#locales>`_ for a list of valid locales.
     """
@@ -668,8 +674,8 @@ class SlashCommand(ApplicationCommand):
             raise TypeError("Callback must be a coroutine.")
         self.callback = func
 
-        self.name_localizations: dict[str, str] | None = kwargs.get(
-            "name_localizations", None
+        self.name_localizations: dict[str, str] = kwargs.get(
+            "name_localizations", MISSING
         )
         _validate_names(self)
 
@@ -680,8 +686,8 @@ class SlashCommand(ApplicationCommand):
         )
 
         self.description: str = description
-        self.description_localizations: dict[str, str] | None = kwargs.get(
-            "description_localizations", None
+        self.description_localizations: dict[str, str] = kwargs.get(
+            "description_localizations", MISSING
         )
         _validate_descriptions(self)
 
@@ -732,6 +738,19 @@ class SlashCommand(ApplicationCommand):
             if option == inspect.Parameter.empty:
                 option = str
 
+            if self._is_typing_annotated(option):
+                type_hint = get_args(option)[0]
+                metadata = option.__metadata__
+                # If multiple Options in metadata, the first will be used.
+                option_gen = (elem for elem in metadata if isinstance(elem, Option))
+                option = next(option_gen, Option())
+                # Handle Optional
+                if self._is_typing_optional(type_hint):
+                    option.input_type = get_args(type_hint)[0]
+                    option.default = None
+                else:
+                    option.input_type = type_hint
+
             if self._is_typing_union(option):
                 if self._is_typing_optional(option):
                     option = Option(option.__args__[0], default=None)
@@ -820,6 +839,9 @@ class SlashCommand(ApplicationCommand):
     def _is_typing_optional(self, annotation):
         return self._is_typing_union(annotation) and type(None) in annotation.__args__  # type: ignore
 
+    def _is_typing_annotated(self, annotation):
+        return get_origin(annotation) is Annotated
+
     @property
     def cog(self):
         return getattr(self, "_cog", MISSING)
@@ -843,9 +865,9 @@ class SlashCommand(ApplicationCommand):
             "description": self.description,
             "options": [o.to_dict() for o in self.options],
         }
-        if self.name_localizations is not None:
+        if self.name_localizations is not MISSING:
             as_dict["name_localizations"] = self.name_localizations
-        if self.description_localizations is not None:
+        if self.description_localizations is not MISSING:
             as_dict["description_localizations"] = self.description_localizations
         if self.is_subcommand:
             as_dict["type"] = SlashCommandOptionType.sub_command.value
@@ -1081,10 +1103,10 @@ class SlashCommandGroup(ApplicationCommand):
         :exc:`.ApplicationCommandError` should be used. Note that if the checks fail then
         :exc:`.CheckFailure` exception is raised to the :func:`.on_application_command_error`
         event.
-    name_localizations: Optional[Dict[:class:`str`, :class:`str`]]
+    name_localizations: Dict[:class:`str`, :class:`str`]
         The name localizations for this command. The values of this should be ``"locale": "name"``. See
         `here <https://discord.com/developers/docs/reference#locales>`_ for a list of valid locales.
-    description_localizations: Optional[Dict[:class:`str`, :class:`str`]]
+    description_localizations: Dict[:class:`str`, :class:`str`]
         The description localizations for this command. The values of this should be ``"locale": "description"``.
         See `here <https://discord.com/developers/docs/reference#locales>`_ for a list of valid locales.
     """
@@ -1119,6 +1141,8 @@ class SlashCommandGroup(ApplicationCommand):
         description: str | None = None,
         guild_ids: list[int] | None = None,
         parent: SlashCommandGroup | None = None,
+        cooldown: CooldownMapping | None = None,
+        max_concurrency: MaxConcurrency | None = None,
         **kwargs,
     ) -> None:
         self.name = str(name)
@@ -1146,13 +1170,40 @@ class SlashCommandGroup(ApplicationCommand):
         self.guild_only: bool | None = kwargs.get("guild_only", None)
         self.nsfw: bool | None = kwargs.get("nsfw", None)
 
-        self.name_localizations: dict[str, str] | None = kwargs.get(
-            "name_localizations", None
+        self.name_localizations: dict[str, str] = kwargs.get(
+            "name_localizations", MISSING
         )
-        self.description_localizations: dict[str, str] | None = kwargs.get(
-            "description_localizations", None
+        self.description_localizations: dict[str, str] = kwargs.get(
+            "description_localizations", MISSING
         )
 
+        # similar to ApplicationCommand
+        from ..ext.commands.cooldowns import BucketType, CooldownMapping, MaxConcurrency
+
+        # no need to getattr, since slash cmds groups cant be created using a decorator
+
+        if cooldown is None:
+            buckets = CooldownMapping(cooldown, BucketType.default)
+        elif isinstance(cooldown, CooldownMapping):
+            buckets = cooldown
+        else:
+            raise TypeError(
+                "Cooldown must be a an instance of CooldownMapping or None."
+            )
+
+        self._buckets: CooldownMapping = buckets
+
+        # no need to getattr, since slash cmds groups cant be created using a decorator
+
+        if max_concurrency is not None and not isinstance(
+            max_concurrency, MaxConcurrency
+        ):
+            raise TypeError(
+                "max_concurrency must be an instance of MaxConcurrency or None"
+            )
+
+        self._max_concurrency: MaxConcurrency | None = max_concurrency
+
     @property
     def module(self) -> str | None:
         return self.__module__
@@ -1163,9 +1214,9 @@ class SlashCommandGroup(ApplicationCommand):
             "description": self.description,
             "options": [c.to_dict() for c in self.subcommands],
         }
-        if self.name_localizations is not None:
+        if self.name_localizations is not MISSING:
             as_dict["name_localizations"] = self.name_localizations
-        if self.description_localizations is not None:
+        if self.description_localizations is not MISSING:
             as_dict["description_localizations"] = self.description_localizations
 
         if self.parent is not None:
@@ -1236,10 +1287,10 @@ class SlashCommandGroup(ApplicationCommand):
             :exc:`.ApplicationCommandError` should be used. Note that if the checks fail then
             :exc:`.CheckFailure` exception is raised to the :func:`.on_application_command_error`
             event.
-        name_localizations: Optional[Dict[:class:`str`, :class:`str`]]
+        name_localizations: Dict[:class:`str`, :class:`str`]
             The name localizations for this command. The values of this should be ``"locale": "name"``. See
             `here <https://discord.com/developers/docs/reference#locales>`_ for a list of valid locales.
-        description_localizations: Optional[Dict[:class:`str`, :class:`str`]]
+        description_localizations: Dict[:class:`str`, :class:`str`]
             The description localizations for this command. The values of this should be ``"locale": "description"``.
             See `here <https://discord.com/developers/docs/reference#locales>`_ for a list of valid locales.
 
@@ -1317,6 +1368,28 @@ class SlashCommandGroup(ApplicationCommand):
         ctx.interaction.data = option
         await command.invoke_autocomplete_callback(ctx)
 
+    async def call_before_hooks(self, ctx: ApplicationContext) -> None:
+        # only call local hooks
+        cog = self.cog
+        if self._before_invoke is not None:
+            # should be cog if @commands.before_invoke is used
+            instance = getattr(self._before_invoke, "__self__", cog)
+            # __self__ only exists for methods, not functions
+            # however, if @command.before_invoke is used, it will be a function
+            if instance:
+                await self._before_invoke(instance, ctx)  # type: ignore
+            else:
+                await self._before_invoke(ctx)  # type: ignore
+
+    async def call_after_hooks(self, ctx: ApplicationContext) -> None:
+        cog = self.cog
+        if self._after_invoke is not None:
+            instance = getattr(self._after_invoke, "__self__", cog)
+            if instance:
+                await self._after_invoke(instance, ctx)  # type: ignore
+            else:
+                await self._after_invoke(ctx)  # type: ignore
+
     def walk_commands(self) -> Generator[SlashCommand | SlashCommandGroup, None, None]:
         """An iterator that recursively walks through all slash commands and groups in this group.
 
@@ -1413,7 +1486,7 @@ class ContextMenuCommand(ApplicationCommand):
     cooldown: Optional[:class:`~discord.ext.commands.Cooldown`]
         The cooldown applied when the command is invoked. ``None`` if the command
         doesn't have a cooldown.
-    name_localizations: Optional[Dict[:class:`str`, :class:`str`]]
+    name_localizations: Dict[:class:`str`, :class:`str`]
         The name localizations for this command. The values of this should be ``"locale": "name"``. See
         `here <https://discord.com/developers/docs/reference#locales>`_ for a list of valid locales.
     """
@@ -1430,8 +1503,8 @@ class ContextMenuCommand(ApplicationCommand):
             raise TypeError("Callback must be a coroutine.")
         self.callback = func
 
-        self.name_localizations: dict[str, str] | None = kwargs.get(
-            "name_localizations", None
+        self.name_localizations: dict[str, str] = kwargs.get(
+            "name_localizations", MISSING
         )
 
         # Discord API doesn't support setting descriptions for context menu commands, so it must be empty
@@ -1506,7 +1579,7 @@ class ContextMenuCommand(ApplicationCommand):
                 "default_member_permissions"
             ] = self.default_member_permissions.value
 
-        if self.name_localizations is not None:
+        if self.name_localizations:
             as_dict["name_localizations"] = self.name_localizations
 
         return as_dict
