@@ -26,81 +26,204 @@ DEALINGS IN THE SOFTWARE.
 from __future__ import annotations
 
 import datetime
-from typing import TYPE_CHECKING, Any, Final, Mapping, Protocol, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Mapping, TypeVar
 
 from _discord.types.embed import EmbedType
 
+
 from . import utils
 from .colour import Colour
 
 __all__ = (
     "Embed",
     "EmbedField",
+    "EmbedAuthor",
+    "EmbedFooter",
+    "EmbedMedia",
+    "EmbedProvider",
 )
 
 
-class _EmptyEmbed:
-    def __bool__(self) -> bool:
-        return False
-
-    def __repr__(self) -> str:
-        return "Embed.Empty"
-
-    def __len__(self) -> int:
-        return 0
-
-
-EmptyEmbed: Final = _EmptyEmbed()
-
-
-class EmbedProxy:
-    def __init__(self, layer: dict[str, Any]):
-        self.__dict__.update(layer)
-
-    def __len__(self) -> int:
-        return len(self.__dict__)
-
-    def __repr__(self) -> str:
-        inner = ", ".join(
-            (f"{k}={v!r}" for k, v in self.__dict__.items() if not k.startswith("_"))
-        )
-        return f"EmbedProxy({inner})"
-
-    def __getattr__(self, attr: str) -> _EmptyEmbed:
-        return EmptyEmbed
-
-
 E = TypeVar("E", bound="Embed")
-T = TypeVar("T")
-MaybeEmpty = Union[T, _EmptyEmbed]
 
 if TYPE_CHECKING:
     from _discord.types.embed import Embed as EmbedData
 
-    class _EmbedFooterProxy(Protocol):
-        text: MaybeEmpty[str]
-        icon_url: MaybeEmpty[str]
 
-    class _EmbedMediaProxy(Protocol):
-        url: MaybeEmpty[str]
-        proxy_url: MaybeEmpty[str]
-        height: MaybeEmpty[int]
-        width: MaybeEmpty[int]
+class EmbedAuthor:
+    """Represents the author on the :class:`Embed` object.
 
-    class _EmbedVideoProxy(Protocol):
-        url: MaybeEmpty[str]
-        height: MaybeEmpty[int]
-        width: MaybeEmpty[int]
+    .. versionadded:: 2.5
 
-    class _EmbedProviderProxy(Protocol):
-        name: MaybeEmpty[str]
-        url: MaybeEmpty[str]
+    Attributes
+    ----------
+    name: :class:`str`
+        The name of the author.
+    url: :class:`str`
+        The URL of the hyperlink created in the author's name.
+    icon_url: :class:`str`
+        The URL of the author icon image.
+    proxy_icon_url: :class:`str`
+        The proxied URL of the author icon image. This can't be set directly, it is set by Discord.
+    """
 
-    class _EmbedAuthorProxy(Protocol):
-        name: MaybeEmpty[str]
-        url: MaybeEmpty[str]
-        icon_url: MaybeEmpty[str]
-        proxy_icon_url: MaybeEmpty[str]
+    def __init__(
+        self,
+        name: str,
+        url: str | None = None,
+        icon_url: str | None = None,
+    ) -> None:
+        self.name: str = name
+        self.url: str | None = url
+        self.icon_url: str | None = icon_url
+        self.proxy_icon_url: str | None = None
+
+    @classmethod
+    def from_dict(cls, data: dict[str, str | None]) -> EmbedAuthor:
+        self = cls.__new__(cls)
+        name = data.get("name")
+        if not name:
+            raise ValueError("name field is required")
+        self.name = name
+        self.url = data.get("url")
+        self.icon_url = data.get("icon_url")
+        self.proxy_icon_url = data.get("proxy_icon_url")
+        return self
+
+    def to_dict(self) -> dict[str, str]:
+        d = {"name": str(self.name)}
+        if self.url:
+            d["url"] = str(self.url)
+        if self.icon_url:
+            d["icon_url"] = str(self.icon_url)
+        return d
+
+    def __len__(self) -> int:
+        """Returns the total number of characters in the author name."""
+        return len(self.name)
+
+    def __repr__(self) -> str:
+        return f"<EmbedAuthor name={self.name!r} url={self.url!r} icon_url={self.icon_url!r}>"
+
+
+class EmbedFooter:
+    """Represents the footer on the :class:`Embed` object.
+
+    .. versionadded:: 2.5
+
+    Attributes
+    ----------
+    text: :class:`str`
+       The text inside the footer.
+    icon_url: :class:`str`
+        The URL of the footer icon image.
+    proxy_icon_url: :class:`str`
+        The proxied URL of the footer icon image. This can't be set directly, it is set by Discord.
+    """
+
+    def __init__(
+        self,
+        text: str,
+        icon_url: str | None = None,
+    ) -> None:
+        self.text: str = text
+        self.icon_url: str | None = icon_url
+        self.proxy_icon_url: str | None = None
+
+    @classmethod
+    def from_dict(cls, data: dict[str, str | None]) -> EmbedFooter:
+        self = cls.__new__(cls)
+        text = data.get("text")
+        if not text:
+            raise ValueError("text field is required")
+        self.text = text
+        self.icon_url = data.get("icon_url")
+        self.proxy_icon_url = data.get("proxy_icon_url")
+        return self
+
+    def to_dict(self) -> dict[str, Any]:
+        d = {"text": str(self.text)}
+        if self.icon_url:
+            d["icon_url"] = str(self.icon_url)
+        return d
+
+    def __len__(self) -> int:
+        """Returns the total number of characters in the footer text."""
+        return len(self.text)
+
+    def __repr__(self) -> str:
+        return f"<EmbedFooter text={self.text!r} icon_url={self.icon_url!r}>"
+
+
+class EmbedMedia:  # Thumbnail, Image, Video
+    """Represents a media on the :class:`Embed` object.
+    This includes thumbnails, images, and videos.
+
+    .. versionadded:: 2.5
+
+    Attributes
+    ----------
+    url: :class:`str`
+        The source URL of the media.
+    proxy_url: :class:`str`
+        The proxied URL of the media.
+    height: :class:`int`
+        The height of the media.
+    width: :class:`int`
+        The width of the media.
+    """
+
+    url: str
+    proxy_url: str | None
+    height: int | None
+    width: int | None
+
+    def __init__(self, url: str):
+        self.url = url
+        self.proxy_url = None
+        self.height = None
+        self.width = None
+
+    @classmethod
+    def from_dict(cls, data: dict[str, str | int]) -> EmbedMedia:
+        self = cls.__new__(cls)
+        self.url = str(data.get("url"))
+        self.proxy_url = (
+            str(proxy_url) if (proxy_url := data.get("proxy_url")) else None
+        )
+        self.height = int(height) if (height := data.get("height")) else None
+        self.width = int(width) if (width := data.get("width")) else None
+        return self
+
+    def __repr__(self) -> str:
+        return f"<EmbedMedia url={self.url!r} proxy_url={self.proxy_url!r}> height={self.height!r} width={self.width!r}>"
+
+
+class EmbedProvider:
+    """Represents a provider on the :class:`Embed` object.
+
+    .. versionadded:: 2.5
+
+    Attributes
+    ----------
+    name: :class:`str`
+        The name of the provider.
+    url: :class:`str`
+        The URL of the provider.
+    """
+
+    name: str | None
+    url: str | None
+
+    @classmethod
+    def from_dict(cls, data: dict[str, str | None]) -> EmbedProvider:
+        self = cls.__new__(cls)
+        self.name = data.get("name")
+        self.url = data.get("url")
+        return self
+
+    def __repr__(self) -> str:
+        return f"<EmbedProvider name={self.name!r} url={self.url!r}>"
 
 
 class EmbedField:
@@ -124,7 +247,7 @@ class EmbedField:
         self.inline = inline
 
     @classmethod
-    def from_dict(cls: type[E], data: Mapping[str, Any]) -> E:
+    def from_dict(cls, data: dict[str, str | bool]) -> EmbedField:
         """Converts a :class:`dict` to a :class:`EmbedField` provided it is in the
         format that Discord expects it to be in.
 
@@ -139,7 +262,7 @@ class EmbedField:
         data: :class:`dict`
             The dictionary to convert into an EmbedField object.
         """
-        self: E = cls.__new__(cls)
+        self = cls.__new__(cls)
 
         self.name = data["name"]
         self.value = data["value"]
@@ -147,7 +270,7 @@ class EmbedField:
 
         return self
 
-    def to_dict(self) -> dict[str, str | bool]:
+    def to_dict(self) -> dict[str, str | bool | None]:
         """Converts this EmbedField object into a dict.
 
         Returns
@@ -161,6 +284,9 @@ class EmbedField:
             "inline": self.inline,
         }
 
+    def __repr__(self) -> str:
+        return f"<EmbedField name={self.name!r} value={self.value!r} inline={self.inline!r}>"
+
 
 class Embed:
     """Represents a Discord embed.
@@ -178,12 +304,6 @@ class Embed:
 
             .. versionadded:: 2.0
 
-    Certain properties return an ``EmbedProxy``, a type
-    that acts similar to a regular :class:`dict` except using dotted access,
-    e.g. ``embed.author.icon_url``. If the attribute
-    is invalid or empty, then a special sentinel value is returned,
-    :attr:`Embed.Empty`.
-
     For ease of use, all parameters that expect a :class:`str` are implicitly
     cast to :class:`str` for you.
 
@@ -212,9 +332,6 @@ class Embed:
     colour: Union[:class:`Colour`, :class:`int`]
         The colour code of the embed. Aliased to ``color`` as well.
         This can be set during initialisation.
-    Empty
-        A special sentinel value used by ``EmbedProxy`` and this class
-        to denote that the value or attribute is empty.
     """
 
     __slots__ = (
@@ -233,38 +350,46 @@ class Embed:
         "description",
     )
 
-    Empty: Final = EmptyEmbed
-
     def __init__(
         self,
         *,
-        colour: int | Colour | _EmptyEmbed = EmptyEmbed,
-        color: int | Colour | _EmptyEmbed = EmptyEmbed,
-        title: MaybeEmpty[Any] = EmptyEmbed,
+        colour: int | Colour | None = None,
+        color: int | Colour | None = None,
+        title: Any | None = None,
         type: EmbedType = "rich",
-        url: MaybeEmpty[Any] = EmptyEmbed,
-        description: MaybeEmpty[Any] = EmptyEmbed,
-        timestamp: datetime.datetime = None,
+        url: Any | None = None,
+        description: Any | None = None,
+        timestamp: datetime.datetime | None = None,
         fields: list[EmbedField] | None = None,
+        author: EmbedAuthor | None = None,
+        footer: EmbedFooter | None = None,
+        image: str | EmbedMedia | None = None,
+        thumbnail: str | EmbedMedia | None = None,
     ):
-        self.colour = colour if colour is not EmptyEmbed else color
+        self.colour = colour if colour else color
         self.title = title
         self.type = type
         self.url = url
         self.description = description
 
-        if self.title is not EmptyEmbed and self.title is not None:
+        if self.title:
             self.title = str(self.title)
 
-        if self.description is not EmptyEmbed and self.description is not None:
+        if self.description:
             self.description = str(self.description)
 
-        if self.url is not EmptyEmbed and self.url is not None:
+        if self.url:
             self.url = str(self.url)
 
         if timestamp:
             self.timestamp = timestamp
-        self._fields: list[EmbedField] = fields or []
+
+        self._fields: list[EmbedField] = fields if fields is not None else []
+
+        self.author = author
+        self.footer = footer
+        self.image = image
+        self.thumbnail = thumbnail
 
     @classmethod
     def from_dict(cls: type[E], data: Mapping[str, Any]) -> E:
@@ -292,18 +417,18 @@ class Embed:
 
         # fill in the basic fields
 
-        self.title = data.get("title", EmptyEmbed)
-        self.type = data.get("type", EmptyEmbed)
-        self.description = data.get("description", EmptyEmbed)
-        self.url = data.get("url", EmptyEmbed)
+        self.title = data.get("title", None)
+        self.type = data.get("type", None)
+        self.description = data.get("description", None)
+        self.url = data.get("url", None)
 
-        if self.title is not EmptyEmbed:
+        if self.title:
             self.title = str(self.title)
 
-        if self.description is not EmptyEmbed:
+        if self.description:
             self.description = str(self.description)
 
-        if self.url is not EmptyEmbed:
+        if self.url:
             self.url = str(self.url)
 
         # try to fill in the more rich fields
@@ -351,7 +476,11 @@ class Embed:
         return self.__class__.from_dict(self.to_dict())
 
     def __len__(self) -> int:
-        total = len(self.title) + len(self.description)
+        total = 0
+        if self.title:
+            total += len(self.title)
+        if self.description:
+            total += len(self.description)
         for field in getattr(self, "_fields", []):
             total += len(field.name) + len(field.value)
 
@@ -390,56 +519,71 @@ class Embed:
         )
 
     @property
-    def colour(self) -> MaybeEmpty[Colour]:
-        return getattr(self, "_colour", EmptyEmbed)
+    def colour(self) -> Colour | None:
+        return getattr(self, "_colour", None)
 
     @colour.setter
-    def colour(self, value: int | Colour | _EmptyEmbed):  # type: ignore
-        if isinstance(value, (Colour, _EmptyEmbed)):
+    def colour(self, value: int | Colour | None):  # type: ignore
+        if value is None or isinstance(value, Colour):
             self._colour = value
         elif isinstance(value, int):
             self._colour = Colour(value=value)
         else:
             raise TypeError(
-                "Expected discord.Colour, int, or Embed.Empty but received"
+                "Expected discord.Colour, int, or None but received"
                 f" {value.__class__.__name__} instead."
             )
 
     color = colour
 
     @property
-    def timestamp(self) -> MaybeEmpty[datetime.datetime]:
-        return getattr(self, "_timestamp", EmptyEmbed)
+    def timestamp(self) -> datetime.datetime | None:
+        return getattr(self, "_timestamp", None)
 
     @timestamp.setter
-    def timestamp(self, value: MaybeEmpty[datetime.datetime]):
+    def timestamp(self, value: datetime.datetime | None):
         if isinstance(value, datetime.datetime):
             if value.tzinfo is None:
                 value = value.astimezone()
             self._timestamp = value
-        elif isinstance(value, _EmptyEmbed):
+        elif value is None:
             self._timestamp = value
         else:
             raise TypeError(
-                "Expected datetime.datetime or Embed.Empty received"
+                "Expected datetime.datetime or None. Received"
                 f" {value.__class__.__name__} instead"
             )
 
     @property
-    def footer(self) -> _EmbedFooterProxy:
-        """Returns an ``EmbedProxy`` denoting the footer contents.
+    def footer(self) -> EmbedFooter | None:
+        """Returns an :class:`EmbedFooter` denoting the footer contents.
 
         See :meth:`set_footer` for possible values you can access.
 
-        If the attribute has no value then :attr:`Empty` is returned.
+        If the footer is not set then `None` is returned.
         """
-        return EmbedProxy(getattr(self, "_footer", {}))  # type: ignore
+        foot = getattr(self, "_footer", None)
+        if not foot:
+            return None
+        return EmbedFooter.from_dict(foot)
+
+    @footer.setter
+    def footer(self, value: EmbedFooter | None):
+        if value is None:
+            self.remove_footer()
+        elif isinstance(value, EmbedFooter):
+            self._footer = value.to_dict()
+        else:
+            raise TypeError(
+                "Expected EmbedFooter or None. Received"
+                f" {value.__class__.__name__} instead"
+            )
 
     def set_footer(
         self: E,
         *,
-        text: MaybeEmpty[Any] = EmptyEmbed,
-        icon_url: MaybeEmpty[Any] = EmptyEmbed,
+        text: Any | None = None,
+        icon_url: Any | None = None,
     ) -> E:
         """Sets the footer for the embed content.
 
@@ -456,10 +600,10 @@ class Embed:
         """
 
         self._footer = {}
-        if text is not EmptyEmbed:
+        if text:
             self._footer["text"] = str(text)
 
-        if icon_url is not EmptyEmbed:
+        if icon_url:
             self._footer["icon_url"] = str(icon_url)
 
         return self
@@ -480,28 +624,45 @@ class Embed:
         return self
 
     @property
-    def image(self) -> _EmbedMediaProxy:
-        """Returns an ``EmbedProxy`` denoting the image contents.
+    def image(self) -> EmbedMedia | None:
+        """Returns an :class:`EmbedMedia` denoting the image contents.
 
-        Possible attributes you can access are:
+        Attributes you can access are:
 
         - ``url``
         - ``proxy_url``
         - ``width``
         - ``height``
 
-        If the attribute has no value then :attr:`Empty` is returned.
+        If the image is not set then `None` is returned.
         """
-        return EmbedProxy(getattr(self, "_image", {}))  # type: ignore
+        img = getattr(self, "_image", None)
+        if not img:
+            return None
+        return EmbedMedia.from_dict(img)
 
-    def set_image(self: E, *, url: MaybeEmpty[Any]) -> E:
+    @image.setter
+    def image(self, value: str | EmbedMedia | None):
+        if value is None:
+            self.remove_image()
+        elif isinstance(value, str):
+            self.set_image(url=value)
+        elif isinstance(value, EmbedMedia):
+            self.set_image(url=value.url)
+        else:
+            raise TypeError(
+                "Expected discord.EmbedMedia, or None but received"
+                f" {value.__class__.__name__} instead."
+            )
+
+    def set_image(self: E, *, url: Any | None) -> E:
         """Sets the image for the embed content.
 
         This function returns the class instance to allow for fluent-style
         chaining.
 
         .. versionchanged:: 1.4
-            Passing :attr:`Empty` removes the image.
+            Passing `None` removes the image.
 
         Parameters
         ----------
@@ -509,7 +670,7 @@ class Embed:
             The source URL for the image. Only HTTP(S) is supported.
         """
 
-        if url is EmptyEmbed:
+        if url is None:
             try:
                 del self._image
             except AttributeError:
@@ -537,28 +698,45 @@ class Embed:
         return self
 
     @property
-    def thumbnail(self) -> _EmbedMediaProxy:
-        """Returns an ``EmbedProxy`` denoting the thumbnail contents.
+    def thumbnail(self) -> EmbedMedia | None:
+        """Returns an :class:`EmbedMedia` denoting the thumbnail contents.
 
-        Possible attributes you can access are:
+        Attributes you can access are:
 
         - ``url``
         - ``proxy_url``
         - ``width``
         - ``height``
 
-        If the attribute has no value then :attr:`Empty` is returned.
+        If the thumbnail is not set then `None` is returned.
         """
-        return EmbedProxy(getattr(self, "_thumbnail", {}))  # type: ignore
+        thumb = getattr(self, "_thumbnail", None)
+        if not thumb:
+            return None
+        return EmbedMedia.from_dict(thumb)
 
-    def set_thumbnail(self: E, *, url: MaybeEmpty[Any]) -> E:
+    @thumbnail.setter
+    def thumbnail(self, value: str | EmbedMedia | None):
+        if value is None:
+            self.remove_thumbnail()
+        elif isinstance(value, str):
+            self.set_thumbnail(url=value)
+        elif isinstance(value, EmbedMedia):
+            self.set_thumbnail(url=value.url)
+        else:
+            raise TypeError(
+                "Expected discord.EmbedMedia, or None but received"
+                f" {value.__class__.__name__} instead."
+            )
+
+    def set_thumbnail(self: E, *, url: Any | None) -> E:
         """Sets the thumbnail for the embed content.
 
         This function returns the class instance to allow for fluent-style
         chaining.
 
         .. versionchanged:: 1.4
-            Passing :attr:`Empty` removes the thumbnail.
+            Passing `None` removes the thumbnail.
 
         Parameters
         ----------
@@ -566,7 +744,7 @@ class Embed:
             The source URL for the thumbnail. Only HTTP(S) is supported.
         """
 
-        if url is EmptyEmbed:
+        if url is None:
             try:
                 del self._thumbnail
             except AttributeError:
@@ -594,45 +772,66 @@ class Embed:
         return self
 
     @property
-    def video(self) -> _EmbedVideoProxy:
-        """Returns an ``EmbedProxy`` denoting the video contents.
+    def video(self) -> EmbedMedia | None:
+        """Returns an :class:`EmbedMedia` denoting the video contents.
 
-        Possible attributes include:
+        Attributes include:
 
         - ``url`` for the video URL.
         - ``height`` for the video height.
         - ``width`` for the video width.
 
-        If the attribute has no value then :attr:`Empty` is returned.
+        If the video is not set then `None` is returned.
         """
-        return EmbedProxy(getattr(self, "_video", {}))  # type: ignore
+        vid = getattr(self, "_video", None)
+        if not vid:
+            return None
+        return EmbedMedia.from_dict(vid)
 
     @property
-    def provider(self) -> _EmbedProviderProxy:
-        """Returns an ``EmbedProxy`` denoting the provider contents.
+    def provider(self) -> EmbedProvider | None:
+        """Returns an :class:`EmbedProvider` denoting the provider contents.
 
         The only attributes that might be accessed are ``name`` and ``url``.
 
-        If the attribute has no value then :attr:`Empty` is returned.
+        If the provider is not set then `None` is returned.
         """
-        return EmbedProxy(getattr(self, "_provider", {}))  # type: ignore
+        prov = getattr(self, "_provider", None)
+        if not prov:
+            return None
+        return EmbedProvider.from_dict(prov)
 
     @property
-    def author(self) -> _EmbedAuthorProxy:
-        """Returns an ``EmbedProxy`` denoting the author contents.
+    def author(self) -> EmbedAuthor | None:
+        """Returns an :class:`EmbedAuthor` denoting the author contents.
 
         See :meth:`set_author` for possible values you can access.
 
-        If the attribute has no value then :attr:`Empty` is returned.
+        If the author is not set then `None` is returned.
         """
-        return EmbedProxy(getattr(self, "_author", {}))  # type: ignore
+        auth = getattr(self, "_author", None)
+        if not auth:
+            return None
+        return EmbedAuthor.from_dict(auth)
+
+    @author.setter
+    def author(self, value: EmbedAuthor | None):
+        if value is None:
+            self.remove_author()
+        elif isinstance(value, EmbedAuthor):
+            self._author = value.to_dict()
+        else:
+            raise TypeError(
+                "Expected discord.EmbedAuthor, or None but received"
+                f" {value.__class__.__name__} instead."
+            )
 
     def set_author(
         self: E,
         *,
         name: Any,
-        url: MaybeEmpty[Any] = EmptyEmbed,
-        icon_url: MaybeEmpty[Any] = EmptyEmbed,
+        url: Any | None = None,
+        icon_url: Any | None = None,
     ) -> E:
         """Sets the author for the embed content.
 
@@ -654,10 +853,10 @@ class Embed:
             "name": str(name),
         }
 
-        if url is not EmptyEmbed:
+        if url:
             self._author["url"] = str(url)
 
-        if icon_url is not EmptyEmbed:
+        if icon_url:
             self._author["icon_url"] = str(icon_url)
 
         return self
