@@ -199,11 +199,11 @@ class MemberConverter(IDConverter[_discord.Member]):
             return _discord.utils.get(
                 members, name=username, discriminator=discriminator
             )
-        else:
-            members = await guild.query_members(argument, limit=100, cache=cache)
-            return _discord.utils.find(
-                lambda m: m.name == argument or m.nick == argument, members
-            )
+        members = await guild.query_members(argument, limit=100, cache=cache)
+        return _discord.utils.find(
+            lambda m: argument in (m.nick, m.name, m.global_name),
+            members,
+        )
 
     async def query_member_by_id(self, bot, guild, user_id):
         ws = bot._get_websocket(shard_id=guild.shard_id)
@@ -320,7 +320,7 @@ class UserConverter(IDConverter[_discord.User]):
             if result is not None:
                 return result
 
-        predicate = lambda u: u.name == arg
+        predicate = lambda u: arg in (u.name, u.global_name)
         result = _discord.utils.find(predicate, state._users.values())
 
         if result is None:
