@@ -58,6 +58,7 @@ if TYPE_CHECKING:
     from .file import File
     from .types import (
         appinfo,
+        application_role_connection,
         audit_log,
         automod,
         channel,
@@ -340,8 +341,10 @@ class HTTPClient:
                                 response, use_clock=self.use_clock
                             )
                             _log.debug(
-                                "A rate limit bucket has been exhausted (bucket: %s,"
-                                " retry: %s).",
+                                (
+                                    "A rate limit bucket has been exhausted (bucket:"
+                                    " %s, retry: %s)."
+                                ),
                                 bucket,
                                 delta,
                             )
@@ -355,7 +358,8 @@ class HTTPClient:
 
                         # we are being rate limited
                         if response.status == 429:
-                            if not response.headers.get("Via") or isinstance(data, str) or ("code" in data and data["code"] == 20016):
+                            retry_after: float = data.get("retry_after", 0)
+                            if not response.headers.get("Via") or isinstance(data, str) or ("code" in data and data["code"] == 20016) or retry_after > 30:
                                 # Banned by Cloudflare more than likely.
                                 raise HTTPException(response, data)
 
@@ -365,15 +369,16 @@ class HTTPClient:
                             )
 
                             # sleep a bit
-                            retry_after: float = data["retry_after"]
                             _log.warning(fmt, retry_after, bucket)
 
                             # check if it's a global rate limit
                             is_global = data.get("global", False)
                             if is_global:
                                 _log.warning(
-                                    "Global rate limit has been hit. Retrying in %.2f"
-                                    " seconds.",
+                                    (
+                                        "Global rate limit has been hit. Retrying in"
+                                        " %.2f seconds."
+                                    ),
                                     retry_after,
                                 )
                                 self._global_over.clear()
@@ -1210,6 +1215,7 @@ class HTTPClient:
         invitable: bool = True,
         applied_tags: SnowflakeList | None = None,
         reason: str | None = None,
+        files: Sequence[File] | None = None,
         embed: embed.Embed | None = None,
         embeds: list[embed.Embed] | None = None,
         nonce: str | None = None,
@@ -1217,43 +1223,74 @@ class HTTPClient:
         stickers: list[sticker.StickerItem] | None = None,
         components: list[components.Component] | None = None,
     ) -> Response[threads.Thread]:
-        payload = {
+        payload: dict[str, Any] = {
             "name": name,
             "auto_archive_duration": auto_archive_duration,
             "invitable": invitable,
         }
-        if content:
-            payload["content"] = content
 
         if applied_tags:
             payload["applied_tags"] = applied_tags
 
-        if embed:
-            payload["embeds"] = [embed]
-
-        if embeds:
-            payload["embeds"] = embeds
-
-        if nonce:
-            payload["nonce"] = nonce
-
-        if allowed_mentions:
-            payload["allowed_mentions"] = allowed_mentions
-
-        if components:
-            payload["components"] = components
-
-        if stickers:
-            payload["sticker_ids"] = stickers
-
         if rate_limit_per_user:
             payload["rate_limit_per_user"] = rate_limit_per_user
-        # TODO: Once supported by API, remove has_message=true query parameter
+
+        message = {}
+
+        if content:
+            message["content"] = content
+
+        if embed:
+            message["embeds"] = [embed]
+
+        if embeds:
+            message["embeds"] = embeds
+
+        if nonce:
+            message["nonce"] = nonce
+
+        if allowed_mentions:
+            message["allowed_mentions"] = allowed_mentions
+
+        if components:
+            message["components"] = components
+
+        if stickers:
+            message["sticker_ids"] = stickers
+
+        if message != {}:
+            payload["message"] = message
+
         route = Route(
             "POST",
-            "/channels/{channel_id}/threads?has_message=true",
+            "/channels/{channel_id}/threads",
             channel_id=channel_id,
         )
+
+        if files:
+            form = [{"name": "payload_json"}]
+
+            attachments = []
+            for index, file in enumerate(files):
+                attachments.append(
+                    {
+                        "id": index,
+                        "filename": file.filename,
+                        "description": file.description,
+                    }
+                )
+                form.append(
+                    {
+                        "name": f"files[{index}]",
+                        "value": file.fp,
+                        "filename": file.filename,
+                        "content_type": "application/octet-stream",
+                    }
+                )
+
+            payload["attachments"] = attachments
+            form[0]["value"] = utils._to_json(payload)
+            return self.request(route, form=form, reason=reason)
         return self.request(route, json=payload, reason=reason)
 
     def join_thread(self, channel_id: Snowflake) -> Response[None]:
@@ -2276,6 +2313,7 @@ class HTTPClient:
             "description",
             "entity_type",
             "entity_metadata",
+            "image",
         )
         payload = {k: v for k, v in payload.items() if k in valid_keys}
 
@@ -2862,6 +2900,31 @@ class HTTPClient:
         )
         return self.request(r, json=payload)
 
+    # Application Role Connections
+
+    def get_application_role_connection_metadata_records(
+        self,
+        application_id: Snowflake,
+    ) -> Response[list[application_role_connection.ApplicationRoleConnectionMetadata]]:
+        r = Route(
+            "GET",
+            "/applications/{application_id}/role-connections/metadata",
+            application_id=application_id,
+        )
+        return self.request(r)
+
+    def update_application_role_connection_metadata_records(
+        self,
+        application_id: Snowflake,
+        payload: list[application_role_connection.ApplicationRoleConnectionMetadata],
+    ) -> Response[list[application_role_connection.ApplicationRoleConnectionMetadata]]:
+        r = Route(
+            "PUT",
+            "/applications/{application_id}/role-connections/metadata",
+            application_id=application_id,
+        )
+        return self.request(r, json=payload)
+
     # Misc
 
     def application_info(self) -> Response[appinfo.AppInfo]:
