@@ -38,7 +38,7 @@ import aiohttp
 
 from .. import utils
 from ..asset import Asset
-from ..channel import PartialMessageable
+from ..channel import ForumChannel, PartialMessageable
 from ..enums import WebhookType, try_enum
 from ..errors import (
     DiscordServerError,
@@ -47,6 +47,7 @@ from ..errors import (
     InvalidArgument,
     NotFound,
 )
+from ..flags import MessageFlags
 from ..http import Route
 from ..message import Attachment, Message
 from ..mixins import Hashable
@@ -622,6 +623,7 @@ def handle_message_parameters(
     view: View | None = MISSING,
     allowed_mentions: AllowedMentions | None = MISSING,
     previous_allowed_mentions: AllowedMentions | None = None,
+    suppress: bool = False,
 ) -> ExecuteWebhookParameters:
     if files is not MISSING and file is not MISSING:
         raise TypeError("Cannot mix file and files keyword arguments.")
@@ -648,8 +650,9 @@ def handle_message_parameters(
         payload["avatar_url"] = str(avatar_url)
     if username:
         payload["username"] = username
-    if ephemeral:
-        payload["flags"] = 64
+
+    flags = MessageFlags(suppress_embeds=suppress, ephemeral=ephemeral)
+    payload["flags"] = flags.value
 
     if allowed_mentions:
         if previous_allowed_mentions is not None:
@@ -827,6 +830,7 @@ class WebhookMessage(Message):
         attachments: list[Attachment] = MISSING,
         view: View | None = MISSING,
         allowed_mentions: AllowedMentions | None = None,
+        suppress: bool | None = MISSING,
     ) -> WebhookMessage:
         """|coro|
 
@@ -868,6 +872,8 @@ class WebhookMessage(Message):
             the view is removed.
 
             .. versionadded:: 2.0
+        suppress: Optional[:class:`bool`]
+            Whether to suppress embeds for the message.
 
         Returns
         -------
@@ -892,10 +898,15 @@ class WebhookMessage(Message):
             thread = Object(self._thread_id)
         elif isinstance(self.channel, Thread):
             thread = Object(self.channel.id)
+        elif isinstance(self.channel, ForumChannel):
+            thread = Object(self.id)
 
         if attachments is MISSING:
             attachments = self.attachments or MISSING
 
+        if suppress is MISSING:
+            suppress = self.flags.suppress_embeds
+
         return await self._state._webhook.edit_message(
             self.id,
             content=content,
@@ -907,6 +918,7 @@ class WebhookMessage(Message):
             view=view,
             allowed_mentions=allowed_mentions,
             thread=thread,
+            suppress=suppress,
         )
 
     async def delete(self, *, delay: float | None = None) -> None:
@@ -1265,6 +1277,7 @@ class Webhook(BaseWebhook):
             "user": {
                 "username": user.name,
                 "discriminator": user.discriminator,
+                "global_name": user.global_name,
                 "id": user.id,
                 "avatar": user._avatar,
             },
@@ -1554,6 +1567,7 @@ class Webhook(BaseWebhook):
         thread: Snowflake = MISSING,
         thread_name: str | None = None,
         wait: Literal[True],
+        delete_after: float = None,
     ) -> WebhookMessage:
         ...
 
@@ -1575,6 +1589,7 @@ class Webhook(BaseWebhook):
         thread: Snowflake = MISSING,
         thread_name: str | None = None,
         wait: Literal[False] = ...,
+        delete_after: float = None,
     ) -> None:
         ...
 
@@ -1762,6 +1777,7 @@ class Webhook(BaseWebhook):
 
         if view is not MISSING and not view.is_finished():
             message_id = None if msg is None else msg.id
+            view.message = None if msg is None else msg
             self._state.store_view(view, message_id)
 
         if delete_after is not None:
@@ -1841,6 +1857,7 @@ class Webhook(BaseWebhook):
         view: View | None = MISSING,
         allowed_mentions: AllowedMentions | None = None,
         thread: Snowflake | None = MISSING,
+        suppress: bool = False,
     ) -> WebhookMessage:
         """|coro|
 
@@ -1888,6 +1905,8 @@ class Webhook(BaseWebhook):
             .. versionadded:: 2.0
         thread: Optional[:class:`~discord.abc.Snowflake`]
             The thread that contains the message.
+        suppress: :class:`bool`
+            Whether to suppress embeds for the message.
 
         Returns
         -------
@@ -1935,6 +1954,7 @@ class Webhook(BaseWebhook):
             view=view,
             allowed_mentions=allowed_mentions,
             previous_allowed_mentions=previous_mentions,
+            suppress=suppress,
         )
 
         thread_id: int | None = None
@@ -1957,6 +1977,7 @@ class Webhook(BaseWebhook):
 
         message = self._create_message(data)
         if view and not view.is_finished():
+            view.message = message
             self._state.store_view(view, message_id)
         return message
 
