@@ -2,6 +2,10 @@
 Discord Advertisement Framework
 """
 import _discord as discord
+
+from . import misc
+from . import events
+
 from .client import *
 from .core import *
 from .dtypes import *
@@ -9,12 +13,8 @@ from .guild import *
 from .message import *
 from .logging import *
 from .web import *
+from .convert import *
+from .remote import *
 
 
-
-from .misc import DOCUMENTATION_MODE
-if DOCUMENTATION_MODE:
-    from .misc import *
-
-
-VERSION = "v2.6.0"
+VERSION = "3.1.1"
