@@ -4,11 +4,12 @@
 """
 from typing import Union, Optional
 from enum import Enum, auto
-from threading import Lock
+from threading import current_thread, Thread
 from datetime import datetime
 from sys import _getframe
 
-from .. import misc
+from ..misc import doc
+from ..events import get_global_event_ctrl, EventID
 
 try:
     from enum_tools.documentation import document_enum
@@ -16,6 +17,9 @@ except ImportError:
     def x(x): return x  # This is only needed for documentation
     document_enum = x
 
+import asyncio
+
+
 __all__ = (
     "TraceLEVELS",
     "trace"
@@ -26,7 +30,7 @@ C_TRACE_FORMAT = "[{date}] ({level}) | {module}: {message} ({reason})"
 
 
 @document_enum
-@misc.doc_category("Logging reference")
+@doc.doc_category("Logging reference")
 class TraceLEVELS(Enum):
     """
     Levels of trace for debug.
@@ -64,23 +68,25 @@ class TraceLEVELS(Enum):
 
 TRACE_COLOR_MAP = {
     TraceLEVELS.DEPRECATED: "\u001b[30m",
-    TraceLEVELS.ERROR:  "\u001b[31m",
-    TraceLEVELS.WARNING:  "\u001b[33m",
-    TraceLEVELS.NORMAL:  "\u001b[37m",
-    TraceLEVELS.DEBUG:  "\u001b[36m",
+    TraceLEVELS.ERROR: "\u001b[31m",
+    TraceLEVELS.WARNING: "\u001b[33m",
+    TraceLEVELS.NORMAL: "\u001b[37m",
+    TraceLEVELS.DEBUG: "\u001b[36m",
 }
 
 
 class GLOBALS:
     """Storage class used for storing global variables of the module."""
     set_level = TraceLEVELS.DEPRECATED
-    lock = Lock()  # For print thread safety
+    loop_thread: Thread = None
+    loop: asyncio.AbstractEventLoop = None
 
 
-@misc.doc_category("Logging reference")
+@doc.doc_category("Logging reference")
 def trace(message: str,
           level: Union[TraceLEVELS, int] = TraceLEVELS.NORMAL,
-          reason: Optional[Exception] = None):
+          reason: Optional[Exception] = None,
+          exception_cls: Optional[Exception] = None):
     """
     Prints a trace to the console.
     This is thread safe.
@@ -106,6 +112,8 @@ def trace(message: str,
         Level of the trace. Defaults to TraceLEVELS.NORMAL.
     reason: Optional[Exception]
         Optional exception object, which caused the prinout.
+    exception_cls: Optional[Exception]
+        An exception to raise after tracing.
     """
     if GLOBALS.set_level >= level:
         frame = _getframe(1)
@@ -118,11 +126,18 @@ def trace(message: str,
                 message=message
         )
 
-        with GLOBALS.lock:
+        if current_thread() is GLOBALS.loop_thread:  # Thread-safe
+            evt = get_global_event_ctrl()
+            evt.emit(EventID.g_trace, level, message)
             print(TRACE_COLOR_MAP[level] + msg + "\033[0m")
+        elif GLOBALS.loop is not None:
+            GLOBALS.loop.call_soon_threadsafe(trace, message, level, reason)
+
+        if exception_cls is not None:
+            raise exception_cls(message) from reason
 
 
-def initialize(level: Union[TraceLEVELS, int, str]):
+def initialize(level: Union[TraceLEVELS, int, str] = TraceLEVELS.NORMAL):
     """
     Initializes the tracing module
 
@@ -144,4 +159,6 @@ def initialize(level: Union[TraceLEVELS, int, str]):
         else:
             trace("Could not find the requested trace level by name (string).", TraceLEVELS.WARNING)
 
+    GLOBALS.loop_thread = current_thread()
     GLOBALS.set_level = level
+    GLOBALS.loop = asyncio.get_running_loop()
