@@ -4,16 +4,16 @@ It contains definitions related to the Selenium integration
 and definitions responsible for making HTTP requests to find servers
 the user might want to shill into.
 """
-from __future__ import annotations
-from typing import Dict, Tuple, Callable, List, Optional, Any
+from typing import Callable, Optional, Any
+from typing import Callable, Optional, Any
 from contextlib import suppress
 from enum import auto, Enum
-
-from datetime import datetime, timedelta
+from datetime import timedelta
 from typeguard import typechecked
 
-from . import misc
 from .logging.tracing import trace, TraceLEVELS
+from .misc import doc
+from .misc.async_util import except_return
 
 import asyncio
 import pathlib
@@ -29,7 +29,8 @@ class GLOBALS:
 
 # ----------------- OPTIONAL ----------------- #
 try:
-    from undetected_chromedriver import Chrome
+    from webdriver_manager.chrome import ChromeDriverManager
+    from undetected_chromedriver import Chrome, ChromeOptions
     from selenium.webdriver.chrome.options import Options
     from selenium.webdriver.remote.webelement import WebElement
     from selenium.webdriver.common.by import By
@@ -39,7 +40,7 @@ try:
     from selenium.webdriver.support.expected_conditions import (
         presence_of_element_located,
         url_contains,
-        url_changes
+        url_changes,
     )
     from selenium.common.exceptions import (
         NoSuchElementException,
@@ -62,14 +63,20 @@ __all__ = (
 
 
 WD_TIMEOUT_SHORT = 5
-WD_TIMEOUT_MED = 30
+WD_TIMEOUT_MED = 15
+WD_TIMEOUT_30 = 30
 WD_TIMEOUT_LONG = 90
+
+WD_FETCH_INVITE_CLOUDFLARE_TRIES = 3
+WD_FETCH_INVITE_CLOUDFLARE_DELAY = 7
+
+WD_CAPTCHA_RETRIES = 3
+
 WD_RD_CLICK_UPPER_N = 5
 WD_RD_CLICK_LOWER_N = 2
-WD_OUTPUT_PATH = pathlib.Path("./daf_web_data")
+WD_OUTPUT_PATH = pathlib.Path.home().joinpath("daf/daf_web_data")
 WD_TOKEN_PATH = WD_OUTPUT_PATH.joinpath("tokens.json")
 WD_PROFILES_PATH = WD_OUTPUT_PATH.joinpath("chrome_profiles")
-WD_QUERY_SLEEP_S = 5
 
 HOVER_CLICK_ACTION_TIME_MS = 500
 
@@ -77,10 +84,12 @@ DISCORD_LOGIN_URL = "https://discord.com/login"
 
 TOP_GG_SEARCH_URL = "https://top.gg/api/client/entities/search"
 TOP_GG_SERVER_JOIN_URL = "https://top.gg/servers/{id}/join"
-TOP_GG_REFRESH_TIME = timedelta(hours=1)
 
 
-@misc.doc_category("Clients")
+XPATH_CAPTCHA = "//iframe[contains(@src, 'captcha')]"
+
+
+@doc.doc_category("Clients")
 class SeleniumCLIENT:
     """
     .. versionadded:: v2.5
@@ -109,6 +118,14 @@ class SeleniumCLIENT:
     proxy: str
         The proxy url to use when connecting to Chrome.
     """
+    __slots__ = (
+        "_username",
+        "_password",
+        "_proxy",
+        "_token",
+        "driver",
+    )
+
     def __init__(self,
                  username: str,
                  password: str,
@@ -120,12 +137,51 @@ class SeleniumCLIENT:
                 "Install them with: pip install discord-advert-framework[web]"
             )
 
-        self._username = username
-        self._password = password
+        self._username = username.strip()
+        self._password = password.strip()
         self._proxy = proxy
         self.driver = None
         self._token = None
 
+    @except_return
+    async def initialize(self) -> None:
+        """
+        Starts the webdriver whenever the framework is started.
+
+        Returns
+        ---------
+        bool
+            ``True`` on success or ``False`` on error.
+        """
+        WD_OUTPUT_PATH.mkdir(exist_ok=True, parents=True)
+        web_data_path = pathlib.Path(WD_PROFILES_PATH, self._username)
+
+        opts = ChromeOptions()
+        opts.add_argument(f"--user-data-dir={web_data_path.absolute()}")
+        opts.add_argument("--profile-directory=Profile 1")
+        opts.add_argument("--no-sandbox")
+        opts.add_argument("--mute-audio")
+        opts.add_argument("--no-first-run")
+        opts.add_argument("--disable-background-networking")
+        opts.add_argument("--disable-sync")
+        opts.add_argument("--disable-popup-blocking")  # For purposes of opening a new window with JavaScript
+
+
+        if self._proxy is not None:
+            proxy = self._proxy.split("://")  # protocol, url
+            if '@' in proxy[1]:  # Username and password also provided
+                trace("Proxy with username and password provided. Enter manually.", TraceLEVELS.WARNING)
+                proxy[1] = proxy[1][proxy[1].find('@') + 1:]
+
+            proxy = f"{proxy[0]}://{proxy[1]}"
+            opts.add_argument(f"--proxy-server={proxy}")
+
+        driver = Chrome(options=opts, driver_executable_path=ChromeDriverManager().install())
+        driver.maximize_window()
+        self.driver = driver
+
+        return await self.login()
+
     def __str__(self) -> str:
         return f"{type(self).__name__}(username={self._username})"
 
@@ -258,12 +314,33 @@ class SeleniumCLIENT:
         trace(f"Fetching invite link from {url}", TraceLEVELS.DEBUG)
         driver = self.driver
         main_window_handle = driver.current_window_handle
-        driver.switch_to.new_window("tab")
-        await self.async_execute(driver.get, url)
-        await self.random_sleep(0.5, 1)
+
+        driver.execute_script(f"window.open('{url}', '_blank');")  # Try to bypass from start
+        await asyncio.sleep(5)
+        invite_handle = driver.window_handles[-1]
+        driver.switch_to.window(invite_handle)
         try:
+            for i in range(WD_FETCH_INVITE_CLOUDFLARE_TRIES):
+                with suppress(NoSuchElementException):
+                    trace("Finding 'challenge-running' cloudflare ID", TraceLEVELS.DEBUG)
+                    if "top.gg" in driver.current_url:
+                        driver.find_element(By.ID, "challenge-running")
+                        # Open a new tab with javascript to bypass detection
+                        trace("Found 'challenge-running' tag", TraceLEVELS.DEBUG)
+                        driver.execute_script("window.open('https://top.gg', '_blank');")
+                        await asyncio.sleep(WD_FETCH_INVITE_CLOUDFLARE_DELAY * (i + 1))
+                        driver.switch_to.window(driver.window_handles[-1])
+                        driver.close()
+                        driver.switch_to.window(invite_handle)
+                        await self.async_execute(driver.refresh)
+
+                trace("Great! 'challenge-running' not found", TraceLEVELS.DEBUG)
+                break
+            else:
+                raise RuntimeError("Could not bypass 'challenge-running'")
+
             await self.async_execute(
-                WebDriverWait(driver, WD_TIMEOUT_SHORT).until,
+                WebDriverWait(driver, WD_TIMEOUT_LONG).until,
                 url_contains("discord.com")
             )
             await self.await_load()
@@ -342,8 +419,8 @@ class SeleniumCLIENT:
         TimeoutError
             The page loading timed-out.
         """
-        await self.random_sleep(2, 3)
         trace("Awaiting Discord load", TraceLEVELS.DEBUG)
+        await asyncio.sleep(3)
         try:
             await self.async_execute(
                 WebDriverWait(self.driver, WD_TIMEOUT_LONG).until_not,
@@ -376,89 +453,26 @@ class SeleniumCLIENT:
             CAPTCHA was not solved in time.
         """
         trace("Awaiting CAPTCHA", TraceLEVELS.DEBUG)
-        driver = self.driver
         await asyncio.sleep(WD_TIMEOUT_SHORT)
-
-        # Find all CAPTCHA iframes
-        captcha_frames = driver.find_elements(
-            By.XPATH,
-            "//iframe[contains(@src, 'captcha')]"
-        )
-        challenge_container = None
-        captcha_button = None
-        captcha_button_frame = None
-        # Find images container and the CAPTCHA button
-        for frame in captcha_frames:
-            driver.switch_to.frame(frame)
-            if challenge_container is None:
-                with suppress(NoSuchElementException):
-                    challenge_container = driver.find_element(
-                        By.XPATH,
-                        "//div[@class='challenge-container']"
-                        "/div[@class='challenge']"
-                    )
-
-            if captcha_button is None:
-                with suppress(NoSuchElementException):
-                    captcha_button = driver.find_element(
-                        By.XPATH,
-                        "//div[@id='checkbox']"
-                    )
-                    captcha_button_frame = frame
-
-            driver.switch_to.default_content()
-
-        if challenge_container is None and captcha_button is None:
-            return  # No CAPTCHA action required
-
-        # Challenge container not found -> click the button to open it
-        if challenge_container is None and captcha_button is not None:
-            driver.switch_to.frame(captcha_button_frame)
-            await self.hover_click(captcha_button)
-            driver.switch_to.default_content()
-
         try:
+            driver = self.driver
             # CAPTCHA detected, wait until it is solved by the user
-            await self.async_execute(
-                WebDriverWait(self.driver, WD_TIMEOUT_LONG).until_not,
-                presence_of_element_located(
-                    (By.XPATH, "//iframe[contains(@src, 'captcha')]")
+            for _ in range(WD_CAPTCHA_RETRIES):
+                await self.async_execute(
+                    WebDriverWait(driver, WD_TIMEOUT_LONG).until_not,
+                    presence_of_element_located(
+                        (By.XPATH, XPATH_CAPTCHA)
+                    )
                 )
-            )
+                await asyncio.sleep(WD_TIMEOUT_SHORT)
+                try:
+                    driver.find_element(By.XPATH, XPATH_CAPTCHA)
+                except NoSuchElementException:
+                    break  # No element found, skip the loop to prevent pointless waiting
+
         except TimeoutException as exc:
             raise TimeoutError("CAPTCHA was not solved by the user") from exc
 
-    async def initialize(self) -> None:
-        """
-        Starts the webdriver whenever the framework is started.
-
-        Raises
-        ----------
-        Any
-            Raised in :py:meth:`~SeleniumCLIENT.login` method.
-        """
-        WD_OUTPUT_PATH.mkdir(exist_ok=True)
-        web_data_path = pathlib.Path(WD_PROFILES_PATH, self._username)
-
-        opts = Options()
-        opts.add_argument(f"--user-data-dir={web_data_path.absolute()}")
-        opts.add_argument("--profile-directory=Profile 1")
-        opts.add_argument("--no-sandbox")
-        opts.add_argument("--mute-audio")
-
-        if self._proxy is not None:
-            proxy = self._proxy.split("://")  # protocol, url
-            if '@' in proxy[1]:
-                proxy[1] = proxy[1][proxy[1].find('@') + 1:]
-
-            proxy = f"{proxy[0]}://{proxy[1]}"
-            opts.add_argument(f"--proxy-server={proxy}")
-
-        driver = Chrome(options=opts)
-        driver.maximize_window()
-        self.driver = driver
-        return await self.login()
-
     async def login(self) -> str:
         """
         Logins to Discord using the webdriver
@@ -481,6 +495,7 @@ class SeleniumCLIENT:
             driver.get(DISCORD_LOGIN_URL)
             await self.await_load()
             await self.random_sleep(2, 3)
+
             # Check if already logged in
             if driver.current_url == DISCORD_LOGIN_URL:
                 # Check previous accounts
@@ -492,6 +507,13 @@ class SeleniumCLIENT:
                     )
                     await self.hover_click(login_bnt)
 
+                await self.async_execute(
+                    WebDriverWait(driver, WD_TIMEOUT_LONG).until,
+                    presence_of_element_located(
+                        (By.XPATH, "//input[@name='email']")
+                    )
+                )
+
                 # Not logged in
                 email_entry = driver.find_element(
                     By.XPATH,
@@ -509,8 +531,8 @@ class SeleniumCLIENT:
                 ActionChains(driver).send_keys(Keys.ENTER).perform()
 
                 await self.await_url_change()
-                await self.await_load()
 
+            await self.await_load()
             return self.update_token_file()
         except (WebDriverException, OSError) as exc:
             raise RuntimeError(
@@ -586,7 +608,7 @@ class SeleniumCLIENT:
 
             join_bnt = driver.find_element(
                 By.XPATH,
-                "//button[@type='button']/div[contains(text(), 'Join')]"
+                "//button[@type='button']/div[contains(text(), 'Join Server')]"
             )
             await self.hover_click(join_bnt)
             await self.random_sleep(3, 5)  # Wait for any CAPTCHA to appear
@@ -600,6 +622,7 @@ class SeleniumCLIENT:
                     "//span[contains(text() , 'Unable to accept')]"
                 )
                 # Element found -> join error
+                ActionChains(driver).send_keys(Keys.ESCAPE).perform()
                 raise RuntimeError(f"The user appears to be banned from the guild w/ invite {invite}")
 
             await self.random_sleep(2, 3)
@@ -610,7 +633,7 @@ class SeleniumCLIENT:
                         (
                             By.XPATH,
                             "//button[@type='button']"
-                            "/div[contains(text(), 'Join')]"
+                            "/div[contains(text(), 'Join Server')]"
                         )
                     )
                 )
@@ -652,7 +675,7 @@ class SeleniumCLIENT:
             ) from exc
 
 
-@misc.doc_category("Web")
+@doc.doc_category("Web")
 class QuerySortBy(Enum):
     """
     Enumerated options that can be passed to the ``sort_by``
@@ -665,17 +688,26 @@ class QuerySortBy(Enum):
     TOTAL_USERS = auto()
 
 
-@misc.doc_category("Web")
+@doc.doc_category("Web")
 class QueryMembers(Enum):
     """
     Enumerated options that can be passed to the ``total_members``
     parameter of :class:`daf.web.GuildDISCOVERY`.
     """
     ALL = 0
-    SUB_100 = (0, 100)
-    B100_1k = (100, 1000)
-    B1k_10k = (1000, 10000)
-    ABV_10k = 1
+    SUB_100 = auto()
+    B100_1k = auto()
+    B1k_10k = auto()
+    ABV_10k = auto()
+
+
+QueryMembers_MAP = {
+    QueryMembers.ALL: (None, None),
+    QueryMembers.SUB_100: (None, 100),
+    QueryMembers.B100_1k: (100, 1000),
+    QueryMembers.B1k_10k: (1000, 10000),
+    QueryMembers.ABV_10k: (10000, None),
+}
 
 
 class QueryResult:
@@ -685,22 +717,16 @@ class QueryResult:
     __slots__ = (
         "id",
         "name",
-        "invite",
-        "updated",
+        "url",
     )
 
-    def __init__(self, id: int, name: str, invite: str) -> None:
+    def __init__(self, id: int, name: str, url: str) -> None:
         self.id = id
         self.name = name
-        self.invite = invite
-        self.updated = datetime.now()
-
-    @property
-    def pending_refresh(self):
-        return datetime.now() - self.updated > TOP_GG_REFRESH_TIME
+        self.url = url
 
 
-@misc.doc_category("Web")
+@doc.doc_category("Web")
 class GuildDISCOVERY:
     """
     Client used for searching servers.
@@ -718,7 +744,6 @@ class GuildDISCOVERY:
         The maximum amount of servers to query.
         Defaults to 15 servers.
     """
-    query_cache: Dict[Tuple[str, QuerySortBy, int], QueryResult] = {}
 
     __slots__ = (
         "prompt",
@@ -742,15 +767,21 @@ class GuildDISCOVERY:
         self.session = None
         self.browser = None
 
+    @except_return
     async def initialize(self, parent: Any):
-        self.session = http.ClientSession()
+        """
+        Initializes guild discovery session.
+        """
         self.browser: SeleniumCLIENT = parent.parent.selenium
         if self.browser is None:
-            raise ValueError(
-                "To use auto-join functionality,"
-                " the account must be provided with username and password."
+            trace(
+                "To use auto-join functionality, the account must be provided with username and password.",
+                TraceLEVELS.ERROR,
+                ValueError
             )
 
+        self.session = http.ClientSession()
+
     async def _close(self):
         """
         Closes under-laying async coroutines.
@@ -768,21 +799,8 @@ class GuildDISCOVERY:
         List[QueryResult]
             List of guilds found.
         """
-        cache_key = (self.prompt, self.sort_by, self.total_members, self.limit)
-        cache_result: List[QueryResult] = self.query_cache.get(cache_key, None)
-        # List[ { 'id': int, 'name': str, 'invite': str } ]"
-        if not (cache_result is None or cache_result[0].pending_refresh):
-            for cached in cache_result:
-                yield cached
-
-            return
-
-        # Update result
-        result_list = []
-        self.query_cache[cache_key] = result_list
-
         params = {
-            "amount": 10,
+            "amount": 50,
             "nsfwLevel": "1",
             "platform": "discord",
             "entityType": "server",
@@ -792,15 +810,13 @@ class GuildDISCOVERY:
             "skip": 0
         }
         total_members = self.total_members
-        if total_members is not QueryMembers.ALL:
-            if total_members is QueryMembers.ABV_10k:
-                params["minUsers"] = 10000
-            else:
-                min_, max_ = total_members.value
-                params["minUsers"] = min_
-                params["maxUsers"] = max_
+        min_users, max_users = QueryMembers_MAP[total_members]
+        if min_users is not None:
+            params["minUsers"] = min_users
+        if max_users is not None:
+            params["maxUsers"] = max_users
 
-        for i in range(0, 1000, 10):
+        for i in range(0, 1000, 50):
             params["skip"] = i
             async with self.session.get(TOP_GG_SEARCH_URL, params=params) as result:
                 if result.status != 200:
@@ -817,12 +833,5 @@ class GuildDISCOVERY:
             for item in data["results"]:
                 id_ = int(item["id"])
                 name = item["name"]
-                url = await self.browser.fetch_invite_link(
-                    TOP_GG_SERVER_JOIN_URL.format(id=id_)
-                )
-                if url is not None:
-                    qr = QueryResult(id_, name, url)
-                    result_list.append(qr)
-                    yield qr
-                else:
-                    await asyncio.sleep(WD_QUERY_SLEEP_S)
+                url = TOP_GG_SERVER_JOIN_URL.format(id=id_)
+                yield QueryResult(id_, name, url)
