@@ -1,4 +1,7 @@
 from datetime import timedelta, datetime
+from typing import List
+
+from daf.events import *
 
 import pytest
 import daf
@@ -11,22 +14,26 @@ TEST_USER_ID = 145196308985020416
 C_FILE_NAME_FORBIDDEN_CHAR = ('<','>','"','/','\\','|','?','*',":")
 
 
-@pytest.mark.asyncio
-async def test_logging_json(channels, guilds, accounts):
+@pytest.fixture(scope="module")
+async def TEXT_MESSAGE(channels, guilds, accounts: List[daf.ACCOUNT]):
+    guild = daf.GUILD(guilds[0], logging=True)
+    await accounts[0].add_server(guild)
+    guild._event_ctrl.remove_listener(EventID.message_ready, guild._advertise)
+    await guild.add_message(tm := daf.TextMESSAGE(None, timedelta(seconds=5), data="Hello World", channels=channels[0]))
+    yield tm
+    await accounts[0].remove_server(guild)
+
+
+async def test_logging_json(TEXT_MESSAGE: daf.TextMESSAGE):
     "Test if json logging works"
-    account = accounts[0]
-    dc_guild, _ = guilds
-    text_channels, _ = channels
+    tm = TEXT_MESSAGE
     try:
         json_logger = daf.LoggerJSON("./History")
         await json_logger.initialize()
         daf.logging._logging._set_logger(json_logger)
 
-        guild = daf.GUILD(dc_guild, logging=True)
-        await guild.initialize(parent=account)
-        guild_context = guild.generate_log_context()
-        account_context = account.generate_log_context()
-        await guild.add_message(tm := daf.TextMESSAGE(None, timedelta(seconds=5), data="Hello World", channels=text_channels))
+        guild_context = tm.parent.generate_log_context()
+        account_context = tm.parent.parent.generate_log_context()
 
         def check_json_results(message_context):
             timestruct = datetime.now()
@@ -46,7 +53,7 @@ async def test_logging_json(channels, guilds, accounts):
                     assert result_json[k] == v, "Resulting data does not match the guild_context"
                 
                 # Check message data
-                message_history = result_json["message_history"]
+                message_history = result_json["message_tracking"][str(account_context["id"])]["messages"]
                 message_history = message_history[0] # Get only last send data
                 message_history.pop("index")
                 message_history.pop("timestamp")
@@ -61,33 +68,33 @@ async def test_logging_json(channels, guilds, accounts):
 
         for d in data:
             await tm.update(data=d)
-            result = await tm._send() 
-            message_ctx = result.message_context
+            message_ctx = await tm._send() 
             await daf.logging.save_log(guild_context, message_ctx, account_context)
             check_json_results(message_ctx)
+
+        # Simulate member join without checking data
+        await daf.logging.save_log(
+            guild_context,
+            invite_context={"id": "ABCDE", "member": {"id": 123456789, "name": "test"}}
+        )
     finally:
         shutil.rmtree("./History", ignore_errors=True)
 
 
-@pytest.mark.asyncio
-async def test_logging_sql(channels, guilds, accounts):
+async def test_logging_sql(TEXT_MESSAGE: daf.TextMESSAGE):
     """
     Tests if SQL logging works(only sqlite).
     It does not test any of the results as it assumes the database
     will raise an exception if anything is wrong.
     """
-    account = accounts[0]
-    dc_guild, _ = guilds
-    text_channels, _ = channels
+    tm = TEXT_MESSAGE
     try:
         sql_logger = daf.LoggerSQL(database="testdb")
         await sql_logger.initialize()
         daf.logging._logging._set_logger(sql_logger)
-        guild = daf.GUILD(dc_guild, logging=True)
-        await guild.initialize(parent=account)
-        guild_context = guild.generate_log_context()
-        account_context = account.generate_log_context()
-        await guild.add_message(tm := daf.TextMESSAGE(None, timedelta(seconds=5), data="Hello World", channels=text_channels))
+
+        guild_context = tm.parent.generate_log_context()
+        account_context = tm.parent.parent.generate_log_context()
 
         data = [
             "Hello World",
@@ -97,8 +104,14 @@ async def test_logging_sql(channels, guilds, accounts):
 
         for d in data:
             await tm.update(data=d)
-            result = await tm._send()
-            message_ctx = result.message_context
+            message_ctx = await tm._send()
             await daf.logging.save_log(guild_context, message_ctx, account_context)
+
+        # Simulate member join without checking data
+        await daf.logging.save_log(
+            guild_context,
+            invite_context={"id": "ABCDE", "member": {"id": 123456789, "name": "test"}}
+        )
     finally:
         os.remove("./testdb.db")
+        daf.logging._logging._set_logger(None)
